Clazz.declarePackage("JM.FF");
(function(){
var c$ = Clazz.decorateAsClass(function(){
this.iVal = null;
this.dVal = null;
this.sVal = null;
Clazz.instantialize(this, arguments);}, JM.FF, "FFParam", null);
})();
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
